@@ -2,8 +2,8 @@
 
 package Perinci::Examples;
 
-our $DATE = '2018-12-07'; # DATE
-our $VERSION = '0.811'; # VERSION
+our $DATE = '2019-04-15'; # DATE
+our $VERSION = '0.812'; # VERSION
 
 use 5.010001;
 use strict;
@@ -483,7 +483,7 @@ _
                  ],
             }]],
             pos => 1,
-            greedy => 1,
+            slurpy => 1,
             description => <<'_',
 
 Completion library can perhaps complete from the `in` value and remember
@@ -564,7 +564,7 @@ _
             schema  => ['array*', of => 'float*'],
             req     => 1,
             pos     => 0,
-            greedy  => 1,
+            slurpy  => 1,
             examples => [[1,2,3], []],
         },
         round => {
@@ -1133,7 +1133,7 @@ Perinci::Examples - Various examples of Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.811 of Perinci::Examples (from Perl distribution Perinci-Examples), released on 2018-12-07.
+This document describes version 0.812 of Perinci::Examples (from Perl distribution Perinci-Examples), released on 2019-04-15.
 
 =head1 DESCRIPTION
 
@@ -1218,6 +1218,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 call_gen_array
 
 Usage:
@@ -1252,6 +1253,7 @@ that contains extra information.
 Return value:  (array[int])
 
 
+
 =head2 call_randlog
 
 Usage:
@@ -1294,6 +1296,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 comment_fruit
 
 Usage:
@@ -1328,6 +1331,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 delay
 
 Usage:
@@ -1366,6 +1370,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 dies
 
 Usage:
@@ -1392,6 +1397,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 err
 
 Usage:
@@ -1424,6 +1430,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 gen_array
 
 Usage:
@@ -1458,6 +1465,7 @@ that contains extra information.
 Return value:  (array[int])
 
 
+
 =head2 gen_hash
 
 Usage:
@@ -1492,6 +1500,7 @@ that contains extra information.
 Return value:  (array[int])
 
 
+
 =head2 gen_random_bytes
 
 Usage:
@@ -1526,6 +1535,7 @@ that contains extra information.
 Return value:  (buf)
 
 
+
 =head2 gen_sample_data
 
 Usage:
@@ -1575,6 +1585,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 merge_hash
 
 Usage:
@@ -1620,6 +1631,7 @@ that contains extra information.
 Return value:  (hash)
 
 
+
 =head2 multi_status
 
 Usage:
@@ -1654,6 +1666,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 noop
 
 Usage:
@@ -1695,6 +1708,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 noop2
 
 Usage:
@@ -1752,6 +1766,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 randlog
 
 Usage:
@@ -1792,6 +1807,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 return_args
 
 Usage:
@@ -1828,6 +1844,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 sum
 
 Usage:
@@ -1884,6 +1901,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 test_args_as_array
 
 Usage:
@@ -1920,6 +1938,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 test_args_as_arrayref
 
 Usage:
@@ -1955,6 +1974,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 test_args_as_hashref
 
 Usage:
@@ -1988,6 +2008,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 test_binary
 
 Usage:
@@ -2048,6 +2069,7 @@ that contains extra information.
 Return value:  (buf)
 
 
+
 =head2 test_common_opts
 
 Usage:
@@ -2106,6 +2128,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 test_completion
 
 Usage:
@@ -2228,6 +2251,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 test_dry_run
 
 Usage:
@@ -2268,6 +2292,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 test_result_naked
 
 Usage:
@@ -2295,6 +2320,7 @@ Arguments ('*' denotes required arguments):
 Return value:  (any)
 
 
+
 =head2 test_validate_args
 
 Usage:
@@ -2329,6 +2355,7 @@ that contains extra information.
 Return value:  (str)
 
 
+
 =head2 undescribed_args
 
 Usage:
@@ -2395,7 +2422,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
