@@ -1,7 +1,7 @@
 package Perinci::Examples::Completion;
 
-our $DATE = '2018-12-07'; # DATE
-our $VERSION = '0.811'; # VERSION
+our $DATE = '2019-04-15'; # DATE
+our $VERSION = '0.812'; # VERSION
 
 use 5.010;
 use strict;
@@ -45,7 +45,7 @@ $SPEC{fruits} = {
             },
             #req => 1,
             pos => 0,
-            greedy => 1,
+            slurpy => 1,
         },
     },
     description => <<'_',
@@ -73,7 +73,7 @@ Perinci::Examples::Completion - More completion examples
 
 =head1 VERSION
 
-This document describes version 0.811 of Perinci::Examples::Completion (from Perl distribution Perinci-Examples), released on 2018-12-07.
+This document describes version 0.812 of Perinci::Examples::Completion (from Perl distribution Perinci-Examples), released on 2019-04-15.
 
 =for Pod::Coverage .*
 
@@ -131,7 +131,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
