@@ -1,7 +1,7 @@
 package Perinci::Examples::ResultNaked;
 
-our $DATE = '2018-12-07'; # DATE
-our $VERSION = '0.811'; # VERSION
+our $DATE = '2019-04-15'; # DATE
+our $VERSION = '0.812'; # VERSION
 
 use 5.010001;
 use strict;
@@ -76,7 +76,7 @@ Perinci::Examples::ResultNaked - Demonstrate `result_naked` property
 
 =head1 VERSION
 
-This document describes version 0.811 of Perinci::Examples::ResultNaked (from Perl distribution Perinci-Examples), released on 2018-12-07.
+This document describes version 0.812 of Perinci::Examples::ResultNaked (from Perl distribution Perinci-Examples), released on 2019-04-15.
 
 =head1 DESCRIPTION
 
@@ -108,7 +108,7 @@ Examples:
 
 =item * Without the optional arg3:
 
- result_naked(arg1 => "abc", arg2 => 10); # -> [200, "OK", ["arg2", 10, "arg1", "abc"]]
+ result_naked(arg1 => "abc", arg2 => 10); # -> [200, "OK", ["arg1", "abc", "arg2", 10]]
 
 =item * With the optional arg3:
 
@@ -116,7 +116,7 @@ Examples:
 
 Result:
 
- [200, "OK", ["arg1", "def", "arg3", 0.5, "arg2", 20]]
+ [200, "OK", ["arg2", 20, "arg1", "def", "arg3", 0.5]]
 
 =back
 
@@ -137,6 +137,7 @@ Arguments ('*' denotes required arguments):
 Return value:  (any)
 
 
+
 =head2 result_not_naked
 
 Usage:
@@ -155,7 +156,7 @@ Examples:
 
 =item * With the optional arg3:
 
- result_not_naked(arg1 => "def", arg2 => 20, arg3 => 0.5); # -> ["arg3", 0.5, "arg1", "def", "arg2", 20]
+ result_not_naked(arg1 => "def", arg2 => 20, arg3 => 0.5); # -> ["arg1", "def", "arg3", 0.5, "arg2", 20]
 
 =back
 
@@ -206,7 +207,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
